* this do-file starts from LSHTM dataset and creates IFRs for all countries adjusting by age and comorbidity.

clear all 
set more off

 graph set window fontface "Times New Roman"

global mypath "~\Dropbox\Corona Crisis"
* this do-file starts from LSHTM dataset and creates IFRs for all countries adjusting by age and comorbidity and health system capacity.

***1) get LHSTM dataset from https://cmmid.github.io/topics/covid19/Global_risk_factors.html
***2) Isolate analysis sheet and save in xlsx
import excel using "$mypath\LSHTM\analysis.xlsx", sh("Analysis") 

foreach var of varlist  E-AEE {
	capture noisily qui tab `var'
	if r(N)==0 {
		drop `var'   		// drop empty variables
	}
	else {
		if !inlist(`var', "Current scenario", "Mid estimates", "Low estimates", "High estimates") in 2 {
			drop  `var'		// keep only columns with data
		}
	}
}

local sets " Male Female Both"
save "$mypath\age and comorbidity adjusted IFRs\temp.dta", replace
tempfile Male Female Both
foreach set of local sets {
	use "$mypath\age and comorbidity adjusted IFRs\temp.dta", clear
		local o=`o'+1
		forv oo=1/3 {
			local word : word `oo' of `sets'
			if `oo' != `o' {
				local keep`oo'  "`word'"
				}
			if `oo'==`o' {
				local keep`oo'  "aaa"
			}
		}
		di "`keep1', `keep2', `keep3'"
		drop if inlist(A, "`keep1'", "`keep2'", "`keep3'")
		local keep1
		local keep2
		local keep3

	//drop if A =="Male" | A=="Female" // keep only aggregate figures
	drop if A =="Back to Dashboard"
	drop if D=="UNPOP location name" | D=="World bank income group" | D=="GBD region" | D=="UNPOP region"

	rename B age_lower
	rename C age_upper

	foreach var of varlist * { // rename variables to countries and scenario before reshape
		*di "`var'"
		
		capture noisily qui replace `var' ="CS" in 1 if `var'=="Current scenario" 
		capture noisily qui replace `var' ="HE" in 1 if `var'=="High estimates" 
		capture noisily qui replace `var' ="ME" in 1 if `var'=="Mid estimates" 
		capture noisily qui replace `var' ="LE" in 1 if `var'=="Low estimates" 
		qui levelsof `var' in 1, local(scenario) clean

		qui levelsof `var' in 2, local(country) clean
		local country = subinstr("`country'", " ","",5)
		local country = subinstr("`country'", "'","",5)
		local country = subinstr("`country'", "-","",5)
		local country = subinstr("`country'", ")","",5)
		local country = subinstr("`country'", "(","",5)
		local country = subinstr("`country'", ".","",5)
		
		if r(N)==1 {
			rename `var' `scenario'_`country'
		} 
	}
	rename Value_GBDlocationname ageGroupName // age group names

	rename A vars
	drop if vars==""
	replace vars = "" if vars=="`set'"
	// drop appendix at bottom of table; figures should be possible to recreate using cleaned data
	drop if inlist(vars, "PREVALENCE OF THE MAIN CATEGORIES OF PRE-EXISTING CONDITIONS", "RESULTS", "Population (millions) for mid-year 2020","Numbers of at-risk population in the working age range", "Percentage of population in the working age range", "ART coverage")

	// fill up variable names
	count
	local N=r(N)
	forvalues i=2/`N' {
		local str =  vars[`i'-1]
		local str1 = vars[`i']
		*di  "`str'"
		*di  "`str1'"
		if  "`str1'" =="" {
			replace vars ="`str'" in `i'
		}
	}
	drop if ageGroupName==""
	
	// assign proper variable names
	local shortnames "pop2020 d_cardiovascular d_kidney d_asthma d_chronicResp d_liverAll d_liverDecompCirrhosis d_liverCirrhosis d_diabetes d_cancersDirectImmuno d_cancersPossImmuno d_HIVAids d_latentTB d_nonlatentTB d_tuberculosis d_chronicNeuro d_sickleCell cond_0_num cond_min1_num_mid cond_min1_share_mid cond_min1_share_low cond_min1_share_high cond_multi_num"
	local longnames `" "Population by 5-year age bands, sex and country, in the year 2020" "Cardiovascular diseases" "Chronic kidney diseases" "Asthma" "Chronic respiratory diseases" "All compensated and decompensated liver disease" "Decompensated cirhossis and other chonic liver disease" "Cirhossis and other chronic liver disease" "Diabetes mellitus" "Cancers with direct immunosuppression" "Cancers with possible immunosuppression" "HIV/AIDS" "Latent TB" "Non-latent TB" "Tuberculosis" "Chronic neurological disorders" "Sickle cell disorders" "Number with 0 conditions" "Number of individuals with at least ONE risk factor (MID estimates)" "Proportion of individuals with at least one risk factor (MID estimates)" "Proportion of individuals with at least one risk factor (LOW estimates using the maximum prevalence among all diseases for a given age/sex)" "Proportion of individuals with at least one risk factor (HIGH estimates assuming independence)" "Number of individuals with multiple conditions"  "'
	local ww=0
	foreach w of local shortnames {
		local ww=`ww'+1
		local rep: word `ww' of `longnames'
		*di "`w', `rep'"
		replace vars = "`w'" if vars =="`rep'"
	}

	// reshape to get data by country
	reshape long CS_ HE_ ME_ LE_, i(ageGroupName vars) j(country) string
	keep CS_ HE_ ME_ LE_ age* vars country 
	rename CS_ value_CS_
	rename HE_ value_HE_
	rename ME_ value_ME_
	rename LE_ value_LE_

	//reshape to get data by country and scenario
	reshape long value_, i(ageGroupName vars country) j(scenario) string
	replace scenario ="Current Scenario" if scenario=="CS_"
	replace scenario ="High Estimate" if scenario=="HE_"
	replace scenario ="Middle Estimate" if scenario=="ME_"
	replace scenario ="Low Estimate" if scenario=="LE_"

	// reshape to get variables in wide format
	destring age_lower, replace
	capture drop __*
	egen t1=median(age_lower), by(ageGroupName)
	replace age_lower = t1 if age_lower!=t1

	egen t2=median(age_upper), by(ageGroupName)
	replace age_upper = t2 if age_upper!=t2
	drop t1 t2
	reshape wide value, i(ageGroupName country scenario) j(vars) string

	sort country scenario age_lower

	// assign labels to variables
	foreach var of varlist value* {
		destring `var', replace
		local sub=substr("`var'", 7,50)
		rename `var' `sub'
		local ww=0
		foreach w of local shortnames {
			local ww=`ww'+1
			if "`sub'"=="`w'" {
				local n=`ww'
			}
		}
		local label : word `n' of `longnames'
		label var `sub' "`label'"
	}
		gen sex="`set'"
		
		save "$mypath\age and comorbidity adjusted IFRs\\`set'.dta", replace
		
	}

import excel using "$mypath\LSHTM\analysis.xlsx", sh("Analysis") clear
	keep D-AEE
	gen count=_n
	drop if count>7
	drop in 1
	drop in 1
	drop count
	replace D="GBDLoc" if D=="GBD location name"
	replace D="UNPOPLoc" if D=="UNPOP location name"
	replace D="WBIncGrp" if D=="World bank income group"
	replace D="GBDReg" if D=="GBD region"
	replace D="UNPOPReg" if D=="UNPOP region"
	sxpose, clear force firstnames
	rename GBDLoc country
	replace country = subinstr(country, " ","",5)
	replace country = subinstr(country, "'","",5)
	replace country = subinstr(country, "-","",5)
	replace country = subinstr(country, ")","",5)
	replace country = subinstr(country, "(","",5)
	replace country = subinstr(country, ".","",5)
	duplicates drop country, force
	drop if UNPOPLoc=="" | UNPOPLoc=="."
	tempfile countries
	save `countries'	
import excel "$mypath\age and comorbidity adjusted IFRs\countryMerger.xlsx", sheet("Sheet1") clear	
	rename A ISO3digitAlpha
	rename B country
	replace country = subinstr(country, " ","",5)
	replace country = subinstr(country, "'","",5)
	replace country = subinstr(country, "-","",5)
	replace country = subinstr(country, ")","",5)
	replace country = subinstr(country, "(","",5)
	replace country = subinstr(country, ".","",5)
	replace country ="Bolivia" if country=="Bolivia,PlurinationalStateof"
	replace country ="Brunei" if country=="BruneiDarussalam"
	replace country ="CotedIvoire" if country=="CôtedIvoire"
	replace country ="DemocraticRepublicoftheCongo" if country=="Congo,theDemocraticRepublicofthe"
	replace country ="FederatedStatesofMicronesia" if country=="Micronesia,FederatedStatesof"
	replace country ="Iran" if country=="Iran,IslamicRepublicof"
	replace country ="Laos" if country=="LaoPeoplesDemocraticRepublic"
	replace country ="Libya" if country=="LibyanArabJamahiriya"
	replace country ="Macedonia" if country=="Macedonia,theformerYugoslavRepublicof"
	replace country ="Moldova" if country=="Moldova,Republicof"
	replace country ="NorthKorea" if country=="Korea,DemocraticPeoplesRepublicof"
	replace country ="Palestine" if country=="PalestinianTerritory,Occupied"
	replace country ="SouthKorea" if country=="Korea,Republicof"
	replace country ="Syria" if country=="SyrianArabRepublic"
	replace country ="TaiwanProvinceofChina" if country=="Taiwan,ProvinceofChina"
	replace country ="Tanzania" if country=="Tanzania,UnitedRepublicof"
	replace country ="TheBahamas" if country=="Bahamas"
	replace country ="TheGambia" if country=="Gambia"
	replace country ="Venezuela" if country=="Venezuela,BolivarianRepublicof"
	replace country ="Vietnam" if country=="VietNam"
	tempfile merger
	save `merger'
	
use "$mypath\age and comorbidity adjusted IFRs\Both.dta", clear
	append using "$mypath\age and comorbidity adjusted IFRs\Male.dta"
	append using "$mypath\age and comorbidity adjusted IFRs\Female.dta"
	merge m:1 country using `countries'
	drop if _merge!=3 // country aggregates
	drop _merge 
	merge m:1 country using `merger'
	drop if _merge==2 
	drop _merge
	
save "$mypath\age and comorbidity adjusted IFRs\comorb_tillmann.dta", replace
	
	erase "$mypath\age and comorbidity adjusted IFRs\temp.dta"
	erase "$mypath\age and comorbidity adjusted IFRs\Both.dta"
	erase "$mypath\age and comorbidity adjusted IFRs\Male.dta"
	erase "$mypath\age and comorbidity adjusted IFRs\Female.dta"
	
use "$mypath\age and comorbidity adjusted IFRs\comorb_tillmann.dta", clear

sort country scenario age_lower sex

keep if scenario=="Current Scenario" 
labmask age_lower , val(ageGroupName)

label var age_lower "Age"

/*input IFRs estimates by age*/

**modi: https://www.medrxiv.org/content/10.1101/2020.04.15.20067074v3

gen IFR_modi_lowlim =.
replace IFR_modi_lowlim=0.01/100 if inlist(age_lower, 30, 35)
replace IFR_modi_lowlim=0.03/100 if inlist(age_lower, 40, 45)
replace IFR_modi_lowlim=0.11/100 if inlist(age_lower, 50, 55)
replace IFR_modi_lowlim=0.46/100 if inlist(age_lower, 60, 65)
replace IFR_modi_lowlim=1.65/100 if inlist(age_lower, 70, 75)
replace IFR_modi_lowlim=4.65/100 if inlist(age_lower, 80, 85)
replace IFR_modi_lowlim=11.42/100 if inlist(age_lower, 90, 95)

gen IFR_modi_DP =.
replace IFR_modi_DP=0.01/100 if inlist(age_lower, 30, 35)
replace IFR_modi_DP=0.04/100 if inlist(age_lower, 40, 45)
replace IFR_modi_DP=0.17/100 if inlist(age_lower, 50, 55)
replace IFR_modi_DP=0.70/100 if inlist(age_lower, 60, 65)
replace IFR_modi_DP=2.53/100 if inlist(age_lower, 70, 75)
replace IFR_modi_DP=7.12/100 if inlist(age_lower, 80, 85)
replace IFR_modi_DP=10.60/100 if inlist(age_lower, 90, 95)

***Salje: https://science.sciencemag.org/content/sci/suppl/2020/05/12/science.abc3517.DC1/abc3517_Salje_SM.pdf

gen IFR_salje=.
replace IFR_salje=0.001/100 if age_lower<20 &sex=="Both"
replace IFR_salje=0.001/100 if age_lower<20 &sex=="Male"
replace IFR_salje=0.001/100 if age_lower<20 &sex=="Female" 

replace IFR_salje=0.007/100 if (age_lower==20|age_lower==25) &sex=="Both"
replace IFR_salje=0.008/100 if (age_lower==20|age_lower==25) &sex=="Male"
replace IFR_salje=0.005/100 if (age_lower==20|age_lower==25) &sex=="Female"

replace IFR_salje=0.02/100 if (age_lower==30|age_lower==35) &sex=="Both"
replace IFR_salje=0.03/100 if (age_lower==30|age_lower==35) &sex=="Male"
replace IFR_salje=0.02/100 if (age_lower==30|age_lower==35) &sex=="Female"

replace IFR_salje=0.06/100 if (age_lower==40|age_lower==45) &sex=="Both"
replace IFR_salje=0.07/100 if (age_lower==40|age_lower==45) &sex=="Male"
replace IFR_salje=0.04/100 if (age_lower==40|age_lower==45) &sex=="Female"

replace IFR_salje=0.2/100 if (age_lower==50|age_lower==55) &sex=="Both"
replace IFR_salje=0.3/100 if (age_lower==50|age_lower==55) &sex=="Male"
replace IFR_salje=0.2/100 if (age_lower==50|age_lower==55) &sex=="Female"

replace IFR_salje=0.9/100 if (age_lower==60|age_lower==65) &sex=="Both"
replace IFR_salje=1.2/100 if (age_lower==60|age_lower==65) &sex=="Male"
replace IFR_salje=0.6/100 if (age_lower==60|age_lower==65) &sex=="Female"

replace IFR_salje=2.4/100 if (age_lower==70|age_lower==75) &sex=="Both"
replace IFR_salje=3.3/100 if (age_lower==70|age_lower==75) &sex=="Male"
replace IFR_salje=1.6/100 if (age_lower==70|age_lower==75) &sex=="Female"

replace IFR_salje=10.1/100 if (age_lower==80|age_lower==85) &sex=="Both"
replace IFR_salje=17.1/100 if (age_lower==80|age_lower==85) &sex=="Male"
replace IFR_salje=5.9/100 if (age_lower==80|age_lower==85) &sex=="Female"

***P(ICU|I, age, sex)

gen IFRICU_low_sex=IFR_salje +0.2/100*26.9/100*(1-(0.7/100)/(26.9/100)) if age_lower<20 & sex=="Male"
replace IFRICU_low_sex=IFR_salje + 0.2/100*16.7/100*(1-(0.5/100)/(16.7/100)) if age_lower<20 & sex=="Female"
replace IFRICU_low_sex=IFR_salje + 0.2/100*22.2/100*(1-(0.6/100)/(22.2/100)) if age_lower<20 & sex=="Both"

replace IFRICU_low_sex=IFR_salje + 0.7/100*14/100*(1-(1.3/100)/(14/100)) if (age_lower==20|age_lower==25) &sex=="Male"
replace IFRICU_low_sex=IFR_salje + 0.6/100*8.6/100*(1-(0.9/100)/(8.6/100)) if (age_lower==20|age_lower==25) &sex=="Female"
replace IFRICU_low_sex=IFR_salje + 0.6/100*11.5/100*(1-(1.1/100)/(11.5/100)) if (age_lower==20|age_lower==25) &sex=="Both"

replace IFRICU_low_sex=IFR_salje + 1.4/100*19.2/100*(1-(2.2/100)/(19.2/100)) if (age_lower==30|age_lower==35) &sex=="Male"
replace IFRICU_low_sex=IFR_salje + 1.1/100*11.9/100*(1-(1.5/100)/(11.9/100)) if (age_lower==30|age_lower==35) &sex=="Female"
replace IFRICU_low_sex=IFR_salje + 1.3/100*15.9/100*(1-(1.9/100)/(15.9/100)) if (age_lower==30|age_lower==35) &sex=="Both"

replace IFRICU_low_sex=IFR_salje + 1.9/100*26.9/100*(1-(3.8/100)/(26.9/100)) if (age_lower==40|age_lower==45) &sex=="Male"
replace IFRICU_low_sex=IFR_salje + 1.6/100*16.6/100*(1-(2.6/100)/(16.6/100)) if (age_lower==40|age_lower==45) &sex=="Female"
replace IFRICU_low_sex=IFR_salje + 1.7/100*22.2/100*(1-(3.3/100)/(22.2/100)) if (age_lower==40|age_lower==45) &sex=="Both"

replace IFRICU_low_sex=IFR_salje + 3.9/100*33.4/100*(1-(7.6/100)/(33.4/100)) if (age_lower==50|age_lower==55) &sex=="Male"
replace IFRICU_low_sex=IFR_salje + 3.2/100*20.7/100*(1-(5.2/100)/(20.7/100)) if (age_lower==50|age_lower==55) &sex=="Female"
replace IFRICU_low_sex=IFR_salje + 3.5/100*27.6/100*(1-(6.5/100)/(27.6/100)) if (age_lower==50|age_lower==55) &sex=="Both"

replace IFRICU_low_sex=IFR_salje + 8.1/100*37.3/100*(1-(14.8/100)/(37.3/100)) if (age_lower==60|age_lower==65) &sex=="Male"
replace IFRICU_low_sex=IFR_salje + 6.2/100*23.1/100*(1-(10.1/100)/(23.1/100)) if (age_lower==60|age_lower==65) &sex=="Female"
replace IFRICU_low_sex=IFR_salje + 7.1/100*30.8/100*(1-(12.6/100)/(30.8/100)) if (age_lower==60|age_lower==65) &sex=="Both"

replace IFRICU_low_sex=IFR_salje + 13.4/100*30.2/100*(1-(24.6/100)/(30.2/100)) if (age_lower==70|age_lower==75) &sex=="Male"
replace IFRICU_low_sex=IFR_salje + 9.6/100*18.7/100*(1-(16.7/100)/(18.7/100)) if (age_lower==70|age_lower==75) &sex=="Female"
replace IFRICU_low_sex=IFR_salje + 11.3/100*24.9/100*(1-(21/100)/(24.9/100)) if (age_lower==70|age_lower==75) &sex=="Both"

replace IFRICU_low_sex=IFR_salje  if (age_lower==80|age_lower==85) &sex=="Male"
replace IFRICU_low_sex=IFR_salje  if (age_lower==80|age_lower==85) &sex=="Female"
replace IFRICU_low_sex=IFR_salje  if (age_lower==80|age_lower==85) &sex=="Both"


******New inputs from Salje for calculating adjustment for health system capacity****
/*P(Hosp|I, age, sex) from p.36 of Salje et al.*/

gen P_hosp_sex=0.2/100 if age_lower<20 & sex=="Male"
replace P_hosp_sex=0.2/100 if age_lower<20 & sex=="Female"
replace P_hosp_sex=0.7/100 if (age_lower==20|age_lower==25) & sex=="Male"
replace P_hosp_sex=0.6/100 if (age_lower==20|age_lower==25) & sex=="Female"
replace P_hosp_sex=1.4/100 if (age_lower==30|age_lower==35) & sex=="Male"
replace P_hosp_sex=1.1/100 if (age_lower==30|age_lower==35) & sex=="Female"
replace P_hosp_sex=1.9/100 if (age_lower==40|age_lower==45) & sex=="Male"
replace P_hosp_sex=1.6/100 if (age_lower==40|age_lower==45) & sex=="Female"
replace P_hosp_sex=3.9/100 if (age_lower==50|age_lower==55) & sex=="Male"
replace P_hosp_sex=3.2/100 if (age_lower==50|age_lower==55) & sex=="Female"
replace P_hosp_sex=8.1/100 if (age_lower==60|age_lower==65) & sex=="Male"
replace P_hosp_sex=6.2/100 if (age_lower==60|age_lower==65) & sex=="Female"
replace P_hosp_sex=13.4/100 if (age_lower==70|age_lower==75) & sex=="Male"
replace P_hosp_sex=9.6/100 if (age_lower==70|age_lower==75) & sex=="Female"
replace P_hosp_sex=45.9/100 if (age_lower==80|age_lower==85) & sex=="Male"
replace P_hosp_sex=23.6/100 if (age_lower==80|age_lower==85) & sex=="Female"

/*p(death| I, Hosp, age, sex, France), p.37 Salje et al.*/
gen IFR_hosp_sex=0.7/100 if age_lower<20 & sex=="Male"
replace IFR_hosp_sex=0.5/100 if age_lower<20 & sex=="Female"
replace IFR_hosp_sex=1.3/100 if (age_lower==20|age_lower==25) & sex=="Male"
replace IFR_hosp_sex=0.9/100 if (age_lower==20|age_lower==25) & sex=="Female"
replace IFR_hosp_sex=2.2/100 if (age_lower==30|age_lower==35) & sex=="Male"
replace IFR_hosp_sex=1.5/100 if (age_lower==30|age_lower==35) & sex=="Female"
replace IFR_hosp_sex=3.8/100 if (age_lower==40|age_lower==45) & sex=="Male"
replace IFR_hosp_sex=2.6/100 if (age_lower==40|age_lower==45) & sex=="Female"
replace IFR_hosp_sex=7.6/100 if (age_lower==50|age_lower==55) & sex=="Male"
replace IFR_hosp_sex=5.2/100 if (age_lower==50|age_lower==55) & sex=="Female"
replace IFR_hosp_sex=14.8/100 if (age_lower==60|age_lower==65) & sex=="Male"
replace IFR_hosp_sex=10.1/100 if (age_lower==60|age_lower==65) & sex=="Female"
replace IFR_hosp_sex=24.6/100 if (age_lower==70|age_lower==75) & sex=="Male"
replace IFR_hosp_sex=16.7/100 if (age_lower==70|age_lower==75) & sex=="Female"
replace IFR_hosp_sex=37.1/100 if (age_lower==80|age_lower==85) & sex=="Male"
replace IFR_hosp_sex=25.2/100 if (age_lower==80|age_lower==85) & sex=="Female"

/*7.15 for LMIC, and (7.15/8.25)*(hCFRumic/hCFRhic) for UMIC*/
gen hosp_adjustment=1 if  WBIncGrp=="High income" 
replace  hosp_adjustment=7.15 if  WBIncGrp=="Low income" |WBIncGrp=="Lower middle income" 
replace  hosp_adjustment=(7.15/8.25)*(2.6/0.5) if  WBIncGrp=="Upper middle income" 

******************************************************************************
******************************************************************************
*/

keep if sex=="Male"|sex=="Female"
*keep if sex=="Both"

gen IFR_raw=IFR_salje 
gen IFRSEV_low_sex=P_hosp_sex

gen IFR_raw_percent=IFR_raw*100
label var age_lower "Lower boundary of age group"

***ALSO INPUT OTHERS WHEN WE HAVE TIME

/*input comorbidity status of covid deaths*/

***italian data checked may 9th, 2020 from https://www.epicentro.iss.it/coronavirus/sars-cov-2-decessi-italia

gen comorb0_death_ita=0.039
gen comorb1_death_ita=0.15
gen comorb2_death_ita=0.213
gen comorb3plus_death_ita=0.598
gen comorb1plus_death_ita=comorb1_death_ita+comorb2_death_ita+comorb3plus_death_ita


***NYC data checked may 17th, 2020 from https://www1.nyc.gov/assets/doh/downloads/pdf/imm/covid-19-daily-data-summary-deaths-05172020-1.pdf


gen comorbunknown_death_nyc_cases=1 if age_lower<20
replace comorbunknown_death_nyc_cases=111 if age_lower>=20&age_lower<45
replace comorbunknown_death_nyc_cases=474 if age_lower>=45&age_lower<65
replace comorbunknown_death_nyc_cases=817 if age_lower>=65&age_lower<75
replace comorbunknown_death_nyc_cases=1816 if age_lower>=75

gen comorb0_death_nyc_cases=1 if age_lower<20
replace comorb0_death_nyc_cases=19 if age_lower>=20&age_lower<45
replace comorb0_death_nyc_cases=71 if age_lower>=45&age_lower<65
replace comorb0_death_nyc_cases=3 if age_lower>=65&age_lower<75
replace comorb0_death_nyc_cases=2 if age_lower>=75

gen comorb1plus_death_nyc_cases=8 if age_lower<20
replace comorb1plus_death_nyc_cases=495 if age_lower>=20&age_lower<45
replace comorb1plus_death_nyc_cases=3011 if age_lower>=45&age_lower<65
replace comorb1plus_death_nyc_cases=3143 if age_lower>=65&age_lower<75
replace comorb1plus_death_nyc_cases=5913 if age_lower>=75

gen tot_death_nyc_cases=comorb1plus_death_nyc_cases+comorb0_death_nyc_cases+comorbunknown_death_nyc_cases
gen knowncomorb_death_nyc_cases=comorb1plus_death_nyc_cases+comorb0_death_nyc_cases

foreach var of varlist comorb*_death_nyc_cases{
	local name =subinstr("`var'", "_cases", "", .)
	gen `name'_overall=`var'/tot_death_nyc_cases
	gen `name'=`var'/knowncomorb_death_nyc_cases
}


label var comorb0_death_nyc "New york city" 
sum comorb0_death_ita

sort age_lower
gen comorb1plus_death_nyc_sex=4985/(4985+11) if sex=="Female"
replace comorb1plus_death_nyc_sex=7563/(85+7563) if sex=="Male"
gen knowncomorb_death_nyc_cases_sex=(4985+11) if sex=="Female"
replace knowncomorb_death_nyc_cases_sex=(85+7563) if sex=="Male"

encode sex , gen(sexcode)
label var sexcode "Sex"
/*
twoway bar comorb1plus_death_nyc_sex  sexcode, legend(label(1 "Percent of fatalities with comorbidities - NYC dataset (left axis)")) ytitle(Percent of fatalities with 1+ comorbidity)  ylabel(0 (0.5)1) xlabel(1 "Female" 2 "Male") col(black*.5) || line comorb1plus_death_ita sexcode, legend(label(2 "Percent of fatalities with comorbidities - Italian average (left axis)")) lc(black) ||  scatter knowncomorb_death_nyc_cases_sex sexcode, yaxis(2)  ytitle( "Number of fatalities", axis(2)) legend(label(3 "Number of fatalities in each group in NYC (right axis)") c(1)) mlc(black)  mc(black*.20) ms(diamond) scheme(s1mono)  fxsize(50) name(a31, replace) ylab(0 (2000) 8000, ax(2)) graphregion(margin(zero)) 


twoway bar comorb1plus_death_nyc  age_lower  if age_lower==20|  age_lower==45| age_lower==65| age_lower==75| age_lower==85, legend(label(1 "Percent of fatalities with comorbidities - NYC dataset (left axis)")) ytitle(Percent of fatalities with 1+ comorbidity) bartype(spanning) ylabel(0 (0.5)1)  col(black*.5) || line comorb1plus_death_ita age_lower, legend(label(2 "Percent of fatalities with comorbidities - Italian average (left axis)")) lc(black) ||  scatter knowncomorb_death_nyc_cases age_lower if  age_lower==35|  age_lower==55| age_lower==70| age_lower==80, yaxis(2)  ytitle( "Number of fatalities", axis(2)) legend(label(3 "Number of fatalities in each group in NYC (right axis)") c(1)) mlc(black) mc(black*.20) ms(diamond)  scheme(s1mono) fxsize(70) name(a32, replace)  ylab(0 (2000) 8000, ax(2)) graphregion(margin(zero)) xlabel(15 (20) 85)

grc1leg a31 a32,  scheme(s1mono) imargin(zero) ycommon 

graph export "$mypath\age and comorbidity adjusted IFRs\graphs_stata\figureA3.png", replace
*/

/* check population */
sort country scenario sex age_lower 
by country scenario sex age_lower : gen pop= cond_0_num+ cond_min1_num_mid
by country scenario sex: egen totpop=total(pop)
by country scenario: egen totpop_tot=total(pop)

gen pop2020_mil=pop2020/1000000
gen pop_mil=pop/1000000

count if abs(pop2020_mil-pop_mil)>1

/*put all in 10 yrs brackets*/

gen age10_lower=floor(age_lower /10)*10
replace age10_lower=80 if age10_lower==90
 
collapse (sum) cond_0_num cond_min1_num_mid pop2020 (mean) IFR_hosp_sex P_hosp_sex IFR_raw IFR_modi_DP IFR_modi_lowlim IFR_salje IFRICU_low_sex IFRSEV_low_sex comorb0_death_ita comorb1_death_ita comorb2_death_ita comorb3plus_death_ita comorb1plus_death_ita  comorbunknown_death_nyc_overall comorbunknown_death_nyc comorb0_death_nyc_overall comorb0_death_nyc comorb1plus_death_nyc_overall comorb1plus_death_nyc (first) UNPOPLoc WBIncGrp GBDReg UNPOPReg ISO3digitAlpha , by(age10_lower country scenario sex)
rename age10_lower age_lower
label var age_lower "Lower boundary of age group"

sort age_lower

/*
twoway line IFR_salje age_lower if sex=="Female" , lc(black*.4) legend(label(1 "Salje et al., Female"))|| line IFR_salje age_lower if sex=="Male" , lc(black*.9) legend(label(2 "Salje et al., Male")) || line IFR_modi_lowlim age_lower  , lc(black*.4) lp(dash) legend(label(3 "Modi et al., lower limit"))||line IFR_modi_DP age_lower ,  lc(black*.9)   lp(dash) legend(label(4 "Modi et al., Diamond Princess"))||scatter IFR_raw age_lower  , ms(x) mc(black) legend(label(5 "IFRs used in this estimation")) scheme(s1mono) xlabel(0(10)90) ytitle(estimated IFR) 

graph export "$mypath\age and comorbidity adjusted IFRs\graphs_stata\figureA2.png", replace

*/
gen IFR_salje_F=IFR_salje*100 if sex=="Female"
gen IFR_salje_M=IFR_salje*100 if sex=="Male"
gen IFRICU_salje_F=IFRICU_low_sex*100 if sex=="Female"
gen IFRICU_salje_M=IFRICU_low_sex*100 if sex=="Male"
gen IFRSEV_salje_F=IFRSEV_low_sex*100 if sex=="Female"
gen IFRSEV_salje_M=IFRSEV_low_sex*100 if sex=="Male"


eststo all1: estpost tabstat  IFR_salje_F IFR_salje_M IFRSEV_salje_F IFRSEV_salje_M if age_lower<90, by(age_lower) statistics(mean) nototal 

esttab all1 using  "$mypath\age and comorbidity adjusted IFRs\graphs_stata\table_IFRSEV_salje.tex", cells("IFR_salje_F(fmt(%9.3g)) IFR_salje_M(fmt(%9.3g))") noobs nomtitle nonumber eqlabels(`e(labels)') varwidth(20) coll("IFR females" "IFR males") replace  tex

/* check population */
sort country scenario sex age_lower 
by country scenario sex age_lower : gen pop= cond_0_num+ cond_min1_num_mid
by country scenario sex: egen totpop_bysex=total(pop)
by country scenario : egen totpop=total(pop) 

gen pop2020_mil=pop2020/1000000
gen pop_mil=pop/1000000

count if abs(pop2020_mil-pop_mil)>1

/* gen share with 0 comorbidity*/
gen cond_0_share=cond_0_num/pop2020
gen cond_min1_share_mid=cond_min1_num_mid/pop2020
gen tot_com=cond_0_share+ cond_min1_share_mid

/*
twoway line cond_0_share age_lower if scenario =="Current Scenario" & country=="Italy" , legend(label(1 "Italy")) lc(black*.4)|| line cond_0_share age_lower if scenario =="Current Scenario" & country=="France",  lc(black) lp(dash) legend(label(2 "France")) scheme(s1mono)  name(comorb, replace) ytitle("Share of population with no conditions") by(sex, com note("  "))  xlabel(0(10)90)   subtitle(, fcolor(none) lstyle(none)) 

graph export "$mypath\age and comorbidity adjusted IFRs\graphs_stata\figureA1.png", replace
*/

** note("Data from Global Burden of Disease dataset assembled by LSHTM""Conditions are: Cardiovascular diseases, Chronic kidney diseases, Chronic respiratory diseases, ""Chronic liver disease, Diabetes mellitus, Cancers with direct immunosuppression, Cancers with ""possible immunosuppression, HIV/AIDS, Tuberculosis, Chronic neurological disorders, Sickle cell ""disorders" ) title(Distribution of underlying conditions)


/*create IFRs
P(d|c,I,age)=P(d|I,age)*P(c|d,I,age)/P(c|I,age)
*/

sort country sex age_lower
gen IFR_age_comorb0=IFR_raw*comorb0_death_ita/cond_0_share if country=="France"
gen IFR_age_comorb1plus=IFR_raw*comorb1plus_death_ita/cond_min1_share_mid if country=="France"
replace IFR_age_comorb1plus=IFR_raw*comorb1plus_death_ita/((cond_min1_num_mid[_n]+cond_min1_num_mid[_n+1])/(pop2020[_n]+pop2020[_n+1])) if country=="France"&age_lower==0
replace IFR_age_comorb1plus=IFR_raw*comorb1plus_death_ita/((cond_min1_num_mid[_n]+cond_min1_num_mid[_n-1])/(pop2020[_n]+pop2020[_n-1])) if country=="France"&age_lower==10


gen IFRICU_age_comorb0=IFRICU_low_sex*comorb0_death_ita/cond_0_share if country=="France"
gen IFRICU_age_comorb1plus=IFRICU_low_sex*comorb1plus_death_ita/cond_min1_share_mid if country=="France"
replace IFRICU_age_comorb1plus=IFRICU_low_sex*comorb1plus_death_ita/((cond_min1_num_mid[_n]+cond_min1_num_mid[_n+1])/(pop2020[_n]+pop2020[_n+1])) if country=="France"&age_lower==0
replace IFRICU_age_comorb1plus=IFRICU_low_sex*comorb1plus_death_ita/((cond_min1_num_mid[_n]+cond_min1_num_mid[_n-1])/(pop2020[_n]+pop2020[_n-1])) if country=="France"&age_lower==10

gen comorb0_sev_ita=0.038
gen comorb1plus_sev_ita=0.962
gen IFRSEV96_age_comorb0=IFRSEV_low_sex*comorb0_sev_ita/cond_0_share if country=="France"
gen IFRSEV96_age_comorb1plus=IFRSEV_low_sex*comorb1plus_sev_ita/cond_min1_share_mid if country=="France"
replace IFRSEV96_age_comorb1plus=IFRSEV_low_sex*comorb1plus_sev_ita/((cond_min1_num_mid[_n]+cond_min1_num_mid[_n+1])/(pop2020[_n]+pop2020[_n+1])) if country=="France"&age_lower==0
replace IFRSEV96_age_comorb1plus=IFRSEV_low_sex*comorb1plus_sev_ita/((cond_min1_num_mid[_n]+cond_min1_num_mid[_n-1])/(pop2020[_n]+pop2020[_n-1])) if country=="France"&age_lower==10

***sensitivity check: P(c|hosp,I)=75%
gen IFRSEV75_age_comorb0=IFRSEV_low_sex*.25/cond_0_share if country=="France"
gen IFRSEV75_age_comorb1plus=IFRSEV_low_sex*.75/cond_min1_share_mid if country=="France"
replace IFRSEV75_age_comorb1plus=IFRSEV_low_sex*.75/((cond_min1_num_mid[_n]+cond_min1_num_mid[_n+1])/(pop2020[_n]+pop2020[_n+1])) if country=="France"&age_lower==0
replace IFRSEV75_age_comorb1plus=IFRSEV_low_sex*.75/((cond_min1_num_mid[_n]+cond_min1_num_mid[_n-1])/(pop2020[_n]+pop2020[_n-1])) if country=="France"&age_lower==10

gen age_lower_sex=string(age_lower)+sex
encode age_lower_sex, gen(agesex)
drop age_lower_sex

xfill IFR_age_comorb0, i(agesex)
xfill IFR_age_comorb1plus, i(agesex)
xfill IFRICU_age_comorb0, i(agesex)
xfill IFRICU_age_comorb1plus, i(agesex)
xfill IFRSEV96_age_comorb0, i(agesex)
xfill IFRSEV96_age_comorb1plus, i(agesex)
xfill IFRSEV75_age_comorb0, i(agesex)
xfill IFRSEV75_age_comorb1plus, i(agesex)

gen hosp_adjustment=1 if  WBIncGrp=="High income" 
replace  hosp_adjustment=7.15 if  WBIncGrp=="Low income" |WBIncGrp=="Lower middle income" 
replace  hosp_adjustment=(7.15/8.25)*(2.6/0.5) if  WBIncGrp=="Upper middle income" 

gen IFR_hsc_comorb0=IFR_age_comorb0*hosp_adjustment/(1+IFR_hosp_sex*(hosp_adjustment-1))
gen IFR_hsc_comorb1plus=IFR_age_comorb1plus*hosp_adjustment/(1+IFR_hosp_sex*(hosp_adjustment-1))

eststo female: estpost tabstat IFR_age_comorb0 IFR_age_comorb1plus  IFRSEV96_age_comorb0  IFRSEV96_age_comorb1plus if age_lower<90&sex=="Female", by(age_lower ) statistics(mean) nototal 

eststo male: estpost tabstat IFR_age_comorb0 IFR_age_comorb1plus  IFRSEV96_age_comorb0  IFRSEV96_age_comorb1plus if age_lower<90&sex=="Male", by(age_lower ) statistics(mean) nototal 

esttab female male using  "$mypath\age and comorbidity adjusted IFRs\graphs_stata\table_cIFR.csv", cells("IFR_age_comorb0 IFR_age_comorb1plus  IFRSEV96_age_comorb0  IFRSEV96_age_comorb1plus") noobs  varwidth(20) coll("IFR no comorbidities" "IFR any comorbidity" "P(severe|I) no comorbidities" "P(severe|I)   any comorbidity") replace  

twoway line IFR_age_comorb0 age_lower if  scenario =="Current Scenario" & country=="France" , legend(label(1 "IFR, no comorbidities")) lc(black)|| line IFR_age_comorb1plus age_lower if scenario =="Current Scenario" & country=="France", legend(label(2 "IFR, any comorbidity") c(2)) lc(black*.4)||line IFRSEV96_age_comorb0 age_lower if  scenario =="Current Scenario" & country=="France" , legend(label(3 "{it:P(severe|I)}, no comorbidities"))  lc(black) lp(dash)|| line IFRSEV96_age_comorb1plus age_lower if scenario =="Current Scenario" & country=="France", legend(label(4 "{it:P(severe|I)}, any comorbidity") c(2))   lc(black*.4) lp(dash)  scheme(s1mono)   ysize(3.5) xlabel(0(10)90) by(sex, com note("  ")) subtitle(, fcolor(none) lstyle(none)) ysc(log) ylabel(0.0001 0.001 0.01 0.1)

** title("Age and comorbidity adjusted IFRs") note("The Age and comorbidity specific IFRs are calculated as age-specific IFRs estimated for France ""by Salje et al. (2020) for ages <40, and for Italy by Modi et al. (2020) for ages >40 multiplied by ""percentage of Covid fatalities having 0 (or any) comorbidity as reported by the ISS, divided by " "fraction of the population having 0 (or any) comorbidity in France, estimated by the LSHTM.")

graph export "$mypath\age and comorbidity adjusted IFRs\graphs_stata\figureA4a.png", replace 
*/
eststo FemaleLMI: estpost tabstat IFR_hsc_comorb0 IFR_hsc_comorb1plus  if age_lower<90&sex=="Female"&(WBIncGrp=="Low income"|WBIncGrp=="Lower middle income"), by(age_lower ) statistics(mean) nototal 
eststo FemaleUMI: estpost tabstat IFR_hsc_comorb0 IFR_hsc_comorb1plus  if age_lower<90&sex=="Female"&(WBIncGrp=="Upper middle income"), by(age_lower ) statistics(mean) nototal 
eststo FemaleHI: estpost tabstat IFR_hsc_comorb0 IFR_hsc_comorb1plus  if age_lower<90&sex=="Female"&(WBIncGrp=="High income"), by(age_lower ) statistics(mean) nototal 


eststo MaleLMI: estpost tabstat IFR_hsc_comorb0 IFR_hsc_comorb1plus  if age_lower<90&sex=="Male"&(WBIncGrp=="Low income"|WBIncGrp=="Lower middle income"), by(age_lower ) statistics(mean) nototal 
eststo MaleUMI: estpost tabstat IFR_hsc_comorb0 IFR_hsc_comorb1plus  if age_lower<90&sex=="Male"&(WBIncGrp=="Upper middle income"), by(age_lower ) statistics(mean) nototal 
eststo MaleHI: estpost tabstat IFR_hsc_comorb0 IFR_hsc_comorb1plus  if age_lower<90&sex=="Male"&(WBIncGrp=="High income"), by(age_lower ) statistics(mean) nototal 

esttab FemaleLMI MaleLMI FemaleUMI MaleUMI  FemaleHI MaleHI using  "$mypath\age and comorbidity adjusted IFRs\graphs_stata\table_cIFR_reg.csv", cells("IFR_hsc_comorb0 IFR_hsc_comorb1plus ") noobs  varwidth(20) coll("IFR_{reg} no comorbidities" "IFR_{reg} any comorbidity") replace 


sort age_lower

twoway line IFR_hsc_comorb0 age_lower if  scenario =="Current Scenario" & WBIncGrp=="High income"  , legend(label(1 "IFR, no comorbidities, HIC")) lc(black)|| line IFR_hsc_comorb1plus age_lower if scenario =="Current Scenario" &  WBIncGrp=="High income", legend(label(2 "IFR, any comorbidity, HIC") c(2)) lc(black*.4)||line IFR_hsc_comorb0 age_lower if  scenario =="Current Scenario" &  WBIncGrp=="Upper middle income", legend(label(3 "IFR, no comorbidities, UMIC"))  lc(black) lp(dash)|| line IFR_hsc_comorb1plus age_lower if scenario =="Current Scenario" & WBIncGrp=="Upper middle income", legend(label(4  "IFR, any comorbidity, UMIC") c(2))   lc(black*.4) lp(dash) ||line IFR_hsc_comorb0 age_lower if  scenario =="Current Scenario" &  ( WBIncGrp=="Low income" |WBIncGrp=="Lower middle income" ), legend(label(5 "IFR, no comorbidities, LIC and LMIC"))  lc(black) lp(dash_dot)|| line IFR_hsc_comorb1plus age_lower if scenario =="Current Scenario" & ( WBIncGrp=="Low income" |WBIncGrp=="Lower middle income" ), legend(label(6  "IFR, any comorbidity,  LIC and LMIC") c(2))   lc(black*.4) lp(dash_dot)  scheme(s1mono)   ysize(3.5) xlabel(0(10)90) by(sex, com note("  ")) subtitle(, fcolor(none) lstyle(none)) ysc(log)  ylabel(0.0001 0.01 0.1)

graph export "$mypath\age and comorbidity adjusted IFRs\graphs_stata\cIFR_regions.png", replace 



/*calculate death numbers at different infection rates*/

gen deathcomorb0=IFR_age_comorb0*cond_0_num
gen deathcomorb1plus=IFR_age_comorb1plus*cond_min1_num_mid
gen deathICUcomorb0=IFRICU_age_comorb0*cond_0_num
gen deathICUcomorb1plus=IFRICU_age_comorb1plus*cond_min1_num_mid
gen deathHSCcomorb0=IFR_hsc_comorb0*cond_0_num
gen deathHSCcomorb1plus=IFR_hsc_comorb1plus*cond_min1_num_mid
gen deathSEV96comorb0=IFRSEV96_age_comorb0*cond_0_num
gen deathSEV96comorb1plus=IFRSEV96_age_comorb1plus*cond_min1_num_mid
gen deathSEV75comorb0=IFRSEV75_age_comorb0*cond_0_num
gen deathSEV75comorb1plus=IFRSEV75_age_comorb1plus*cond_min1_num_mid

foreach n in 5 20 22 40 50 60 80 100 {
gen deathcomorb0_`n'=deathcomorb0*`n'/100
gen deathcomorb1plus_`n'=deathcomorb1plus*`n'/100
gen deathall_`n'=deathcomorb1plus_`n' + deathcomorb0_`n'
bys country scenario sex: egen deathtotal_bysex_`n'=total(deathall_`n')
bys country scenario: egen deathtotal_`n'=total(deathall_`n')

gen deathICUcomorb0_`n'=deathICUcomorb0*`n'/100
gen deathICUcomorb1plus_`n'=deathICUcomorb1plus*`n'/100
gen deathICUall_`n'=deathICUcomorb1plus_`n' + deathICUcomorb0_`n'
bys country scenario sex: egen deathICUtotal_bysex_`n'=total(deathICUall_`n')
bys country scenario: egen deathICUtotal_`n'=total(deathICUall_`n')

gen deathHSCcomorb0_`n'=deathHSCcomorb0*`n'/100
gen deathHSCcomorb1plus_`n'=deathHSCcomorb1plus*`n'/100
gen deathHSCall_`n'=deathHSCcomorb1plus_`n' + deathHSCcomorb0_`n'
bys country scenario sex: egen deathHSCtotal_bysex_`n'=total(deathHSCall_`n')
bys country scenario: egen deathHSCtotal_`n'=total(deathHSCall_`n')

gen deathSEV96comorb0_`n'=deathSEV96comorb0*`n'/100
gen deathSEV96comorb1plus_`n'=deathSEV96comorb1plus*`n'/100
gen deathSEV96all_`n'=deathSEV96comorb1plus_`n' + deathSEV96comorb0_`n'
bys country scenario sex: egen deathSEV96total_bysex_`n'=total(deathSEV96all_`n')
bys country scenario: egen deathSEV96total_`n'=total(deathSEV96all_`n')

gen deathSEV75comorb0_`n'=deathSEV75comorb0*`n'/100
gen deathSEV75comorb1plus_`n'=deathSEV75comorb1plus*`n'/100
gen deathSEV75all_`n'=deathSEV75comorb1plus_`n' + deathSEV75comorb0_`n'
bys country scenario sex: egen deathSEV75total_bysex_`n'=total(deathSEV75all_`n')
bys country scenario: egen deathSEV75total_`n'=total(deathSEV75all_`n')
}

by country scenario: egen totpop_tot=total(pop)
by country scenario sex: egen totpop_sex=total(pop)



gen IFR_country=deathtotal_100/totpop_tot
gen IFR_country_sex=deathtotal_bysex_100/totpop_sex

gen IFRICU_country=deathICUtotal_100/totpop_tot
gen IFRICU_country_sex=deathICUtotal_bysex_100/totpop_sex

gen IFRHSC_country=deathHSCtotal_100/totpop_tot
gen IFRHSC_country_sex=deathHSCtotal_bysex_100/totpop_sex

gen IFRSEV96_country=deathSEV96total_100/totpop_tot
gen IFRSEV96_country_sex=deathSEV96total_bysex_100/totpop_sex

gen IFRSEV75_country=deathSEV75total_100/totpop_tot
gen IFRSEV75_country_sex=deathSEV75total_bysex_100/totpop_sex

bys country scenario: egen totdeath_below65=total(deathall_100) if age_lower<65
by country scenario: egen totdeath_65above=total(deathall_100) if age_lower>=65
by country scenario: egen totICUdeath_below65=total(deathICUall_100) if age_lower<65
by country scenario: egen totICUdeath_65above=total(deathICUall_100) if age_lower>=65
by country scenario: egen totHSCdeath_below65=total(deathHSCall_100) if age_lower<65
by country scenario: egen totHSCdeath_65above=total(deathHSCall_100) if age_lower>=65

by country scenario: egen totpop_below65=total(pop) if age_lower<65
by country scenario: egen totpop_65above=total(pop) if age_lower>=65
gen IFR_country_below65=totdeath_below65/totpop_below65
gen IFR_country_65above=totdeath_65above/totpop_65above

gen IFRICU_country_below65=totICUdeath_below65/totpop_below65
gen IFRICU_country_65above=totICUdeath_65above/totpop_65above

gen IFRHSC_country_below65=totHSCdeath_below65/totpop_below65
gen IFRHSC_country_65above=totHSCdeath_65above/totpop_65above
encode country, g(c)

xfill totdeath_below65, i(c)
xfill totdeath_65above, i(c)
xfill totICUdeath_below65, i(c)
xfill totICUdeath_65above, i(c)
xfill totHSCdeath_below65, i(c)
xfill totHSCdeath_65above, i(c)
gen death_below_above65=totdeath_below65/totdeath_65above
gen death_below65_share=totdeath_below65/deathtotal_100
gen deathICU_below65_share=totICUdeath_below65/deathICUtotal_100
gen deathICU_below_above65=totICUdeath_below65/totICUdeath_65above
gen deathHSC_below65_share=totHSCdeath_below65/deathHSCtotal_100
gen deathHSC_below_above65=totHSCdeath_below65/totHSCdeath_65above

xfill IFRICU_country_below65, i(c)
xfill IFRICU_country_65above, i(c)
xfill IFR_country_below65, i(c)
xfill IFR_country_65above, i(c)


sort country scenario sex age_lower

gen age_mid=age_lower+5


bys country:egen cond_0_num_country=total( cond_0_num)
bys country:egen cond_min1_num_mid_country=total( cond_min1_num_mid )
bys country:egen average_age=wtmean(age_lower) , weight(pop2020)

bys country:gen cond_0_share_country=cond_0_num_country/totpop
bys country:gen cond_min1_share_country=cond_min1_num_mid_country /totpop

** Population structure **
replace UNPOPReg="Asia" if UNPOPReg=="Africa"& GBDReg=="Southeast Asia"
replace UNPOPReg="Africa" if GBDReg=="North Africa and Middle East"
replace UNPOPReg="Europe" if GBDReg=="Western Europe"

preserve
keep GBDReg UNPOPReg country sex IFR_country_sex IFR_country  IFRHSC_country_sex IFRHSC_country  IFRSEV96_country_sex IFRSEV96_country  IFRSEV75_country_sex IFRSEV75_country  IFRICU_country_sex IFRICU_country cond_0_share_country  cond_min1_share_country average_age deathHSC_below65_share hosp_adjustment

duplicates drop

gen HSC_multiplier=IFRHSC_country/IFR_country

reshape wide IFR_country_sex IFRICU_country_sex IFRHSC_country_sex IFRSEV96_country_sex IFRSEV75_country_sex, i(country) j(sex) string

outsheet  using "$mypath\age and comorbidity adjusted IFRs\IFRICU_country_salje_sex_hsc_ageonly.csv", comma replace


outsheet GBDReg UNPOPReg country IFR_country IFRHSC_country   cond_min1_share_country average_age deathHSC_below65_share hosp_adjustment HSC_multiplier using "$mypath\age and comorbidity adjusted IFRs\Interactive_Map_data_ageonly.csv", comma replace
restore 


/* FINAL GRAPH */

replace GBDReg="High-income Asia Pacific" if country=="TaiwanProvinceofChina"
encode GBDReg, g(GBDReg_code)

/*generate weighted averages of IFR and IFRICU by GBDReg*/
bys GBDReg_code age_lower: egen pop2020_reg=total(pop2020)
bys GBDReg_code age_lower: egen cond_0_num_reg=total(cond_0_num)
bys GBDReg_code age_lower: egen cond_min1_num_mid_reg=total(cond_min1_num_mid)
bys GBDReg_code age_lower: gen cond_min1_share_reg=cond_min1_num_mid_reg/pop2020_reg
bys GBDReg_code age_lower: gen cond_0_share_reg=cond_0_num_reg/pop2020_reg

bys GBDReg_code: egen deathtotal_reg_100=total(deathall_100)
bys GBDReg_code: egen deathICUtotal_reg_100=total(deathICUall_100)
bys GBDReg_code: egen deathHSCtotal_reg_100=total(deathHSCall_100)
bys GBDReg_code: egen deathSEV96total_reg_100=total(deathSEV96all_100)
bys GBDReg_code: egen deathSEV75total_reg_100=total(deathSEV75all_100)
bys GBDReg_code: egen pop2020tot_reg=total(pop2020)

bys GBDReg_code: gen IFR_GBDReg=deathtotal_reg_100/pop2020tot_reg *100
bys GBDReg_code: gen IFRICU_GBDReg=deathICUtotal_reg_100/pop2020tot_reg *100
bys GBDReg_code: gen IFRHSC_GBDReg=deathHSCtotal_reg_100/pop2020tot_reg *100
bys GBDReg_code: gen IFRSEV96_GBDReg=deathSEV96total_reg_100/pop2020tot_reg *100
bys GBDReg_code: gen IFRSEV75_GBDReg=deathSEV75total_reg_100/pop2020tot_reg *100
bys GBDReg_code: gen IFRminICU_GBDReg=IFRICU_GBDReg-IFR_GBDReg

/*then by sex*/
bys GBDReg_code age_lower sex: egen pop2020_reg_sex=total(pop2020)
bys GBDReg_code age_lower sex: egen cond_0_num_reg_sex=total(cond_0_num)
bys GBDReg_code age_lower sex: egen cond_min1_num_mid_reg_sex=total(cond_min1_num_mid)
bys GBDReg_code age_lower sex: gen cond_min1_share_reg_sex=cond_min1_num_mid_reg/pop2020_reg
bys GBDReg_code age_lower sex: gen cond_0_share_reg_sex=cond_0_num_reg/pop2020_reg

bys GBDReg_code sex: egen deathtotal_reg_100_sex=total(deathall_100)
bys GBDReg_code sex: egen deathICUtotal_reg_100_sex=total(deathICUall_100)
bys GBDReg_code sex: egen deathHSCtotal_reg_100_sex=total(deathHSCall_100)
bys GBDReg_code sex: egen deathSEV96total_reg_100_sex=total(deathSEV96all_100)
bys GBDReg_code sex: egen deathSEV75total_reg_100_sex=total(deathSEV75all_100)
bys GBDReg_code sex: egen pop2020tot_reg_sex=total(pop2020)

bys GBDReg_code sex: gen IFR_GBDReg_sex=deathtotal_reg_100_sex/pop2020tot_reg_sex *100
bys GBDReg_code sex: gen IFRICU_GBDReg_sex=deathICUtotal_reg_100_sex/pop2020tot_reg_sex *100
bys GBDReg_code sex: gen IFRHSC_GBDReg_sex=deathHSCtotal_reg_100_sex/pop2020tot_reg_sex *100
bys GBDReg_code sex: gen IFRSEV96_GBDReg_sex=deathSEV96total_reg_100_sex/pop2020tot_reg_sex *100
bys GBDReg_code sex: gen IFRSEV75_GBDReg_sex=deathSEV75total_reg_100_sex/pop2020tot_reg_sex *100

gen zeroes=0


local popgraphs
local namegraphs
local ifrgraphs


bys country age_lower: egen female_pop= mean(pop2020) if sex=="Female"
bys country age_lower: egen male_pop= mean(pop2020) if sex=="Male"
gen countryage=country+string(age_lower)
encode countryage , g(ca)
drop countryage
 xfill female_pop, i(ca)
 xfill male_pop, i(ca)
 
bys country age_lower: egen female_IFR_GBDReg= mean(IFR_GBDReg_sex) if sex=="Female"
bys country age_lower: egen male_IFR_GBDReg= mean(IFR_GBDReg_sex) if sex=="Male"
 xfill female_IFR_GBDReg, i(ca)
 xfill male_IFR_GBDReg, i(ca)

bys country age_lower: egen female_IFRICU_GBDReg= mean(IFRICU_GBDReg_sex) if sex=="Female"
bys country age_lower: egen male_IFRICU_GBDReg= mean(IFRICU_GBDReg_sex) if sex=="Male"
 xfill female_IFRICU_GBDReg, i(ca)
 xfill male_IFRICU_GBDReg, i(ca)
 
bys country age_lower: egen female_IFRHSC_GBDReg= mean(IFRHSC_GBDReg_sex) if sex=="Female"
bys country age_lower: egen male_IFRHSC_GBDReg= mean(IFRHSC_GBDReg_sex) if sex=="Male"
 xfill female_IFRHSC_GBDReg, i(ca)
 xfill male_IFRHSC_GBDReg, i(ca)
 
bys country age_lower: egen female_IFRSEV96_GBDReg= mean(IFRSEV96_GBDReg_sex) if sex=="Female"
bys country age_lower: egen male_IFRSEV96_GBDReg= mean(IFRSEV96_GBDReg_sex) if sex=="Male"
 xfill female_IFRSEV96_GBDReg, i(ca)
 xfill male_IFRSEV96_GBDReg, i(ca)
 
 gen female_IFRminICU_GBDReg=female_IFRICU_GBDReg-female_IFR_GBDReg
 gen male_IFRminICU_GBDReg=male_IFRICU_GBDReg-male_IFR_GBDReg

gen female_male_ratio=female_pop/male_pop


drop GBDReg_code
sort IFR_GBDReg 
bys IFR_GBDReg:g n=_n
replace n=. if n!=1
sort n IFR_GBDReg
by n: gen GBDReg_code =_n if n==1
 labmask GBDReg_code, val(GBDReg)
 
 xfill GBDReg_code, i(IFR_GBDReg)
 
 
 
 

save  "$mypath\age and comorbidity adjusted IFRs\calculatedIFR.dta", replace
use   "~\Dropbox\Corona Crisis\age and comorbidity adjusted IFRs\calculatedIFR.dta", clear



local popgraphs
local namegraphs
local ifrgraphs
*local sexgraphs

   graph bar zeroes , stack over(age_lower, axis(off) gap(*0.1))  bar(1 ,color(white)) title(IFR, angle(horizontal) position(0) size(huge)) ytitle("") legend(off) name(IFR, replace) scheme(s1mono)  plotregion(margin(zero)) graphregion(margin(zero)) ylabel(none) fxsize(10)

  graph bar zeroes , stack over(age_lower, axis(off) gap(*0.1))  bar(1 ,color(white)) title(Adjusted IFR, angle(horizontal) position(0) size(huge)) ytitle("") legend(off) name(Adj, replace) scheme(s1mono)  plotregion(margin(zero)) graphregion(margin(zero)) ylabel(none) fxsize(10)

 graph bar zeroes , stack over(age_lower, axis(off) gap(*0.1))  bar(1 ,color(white)) title(Severe cases, angle(horizontal) position(0) size(huge)) ytitle("") legend(off) name(Severe, replace) scheme(s1mono)  plotregion(margin(zero)) graphregion(margin(zero)) ylabel(none) fxsize(10)
 
 
levelsof GBDReg_code, l(GBDReg_codes)

foreach GBDReg_code of local GBDReg_codes{ 

levelsof GBDReg if GBDReg_code==`GBDReg_code', l(GBDReg)
sum pop2020tot_reg if GBDReg_code==`GBDReg_code'

local GBDReg_pop =int(r(mean)/10000)/100

    graph bar zeroes  if GBDReg_code==`GBDReg_code', stack over(age_lower, axis(off) gap(*0.1))  bar(1 ,color(white)) title( `GBDReg' `GBDReg_pop' million, angle(horizontal) position(0) size(huge)) ytitle("") legend(label(1 "Region name and Population in millions")) name(names`GBDReg_code', replace) scheme(s1mono)  plotregion(margin(zero)) graphregion(margin(zero)) ylabel(none) 
	
  graph bar cond_0_num_reg cond_min1_num_mid_reg  if GBDReg_code==`GBDReg_code', stack over(age_lower, axis(off) gap(*0.1)) outergap(*0.1)  bar(1 ,color(black*.3)) bar(2, color(black*.6)) title("") legend(off)  ylabel(none) name(pops`GBDReg_code', replace) scheme(s1mono)  plotregion(margin(zero)) graphregion(margin(zero)) 
  
  *graph bar  male_pop  female_pop if GBDReg_code==`GBDReg_code', over(age_lower, axis(off) gap(*0.1)) stack perc bar(1, c(black*.6)) bar(2, c(black*.3)) title("") legend(off)  ylabel(none) ytitle("") name(sex`GBDReg_code', replace) scheme(s1mono)  plotregion(margin(zero)) graphregion(margin(zero)) 

 * graph bar cond_0_share_reg cond_min1_share_reg if GBDReg_code==`GBDReg_code', over(age_lower, axis(off) gap(*0.1)) outergap(*0.1) stack bar(1 ,color(146 195 51)) bar(2, color(gold)) title("") legend(off)  ylabel(none) name(coms`GBDReg_code', replace) scheme(s1mono)  plotregion(margin(zero)) graphregion(margin(zero)) 
 
 	sum IFR_GBDReg if  GBDReg_code==`GBDReg_code'
	local IFR_GBDReg=strofreal(r(mean), "%9.2f")

 	sum IFRHSC_GBDReg if  GBDReg_code==`GBDReg_code'
	local IFRHSC_GBDReg=strofreal(r(mean), "%9.2f")

 	sum IFRSEV96_GBDReg if  GBDReg_code==`GBDReg_code'
	local IFRSEV96_GBDReg=strofreal(r(mean), "%9.2f")

  graph hbar  IFR_GBDReg if GBDReg_code==`GBDReg_code',  bar(1 ,color(black%60))   title("`IFR_GBDReg'", position(9) size(vhuge)) ylabel(none) legend(off)  name(IFR_GBDReg`GBDReg_code', replace) scheme(s1mono)  plotregion(margin(zero) lc(white)) graphregion(margin(zero) lc(white))  ytitle("") ysc(range(0 5.5))  outergap(0)  ylabel(0(.5)5.5, gstyle(major) nolab notick) 

  graph hbar  IFRHSC_GBDReg if GBDReg_code==`GBDReg_code',  bar(1 ,color(black%45))  title("`IFRHSC_GBDReg'", position(9) size(vhuge)) ylabel(none) legend(off)  name(IFRHSC_GBDReg`GBDReg_code', replace) scheme(s1mono)  plotregion(margin(zero) lc(white)) graphregion(margin(zero))  ytitle("") ysc(range(0 5.5))  outergap(0)  ylabel(0(.5)5.5, gstyle(major) nolab notick) 

    graph hbar  IFRSEV96_GBDReg  if GBDReg_code==`GBDReg_code',   bar(1,color(black%30)) title("`IFRSEV96_GBDReg'", position(9) size(vhuge)) ylabel(none) legend(off)  name(IFRSEV96_GBDReg`GBDReg_code', replace) scheme(s1mono)  plotregion(margin(zero) lc(white)) graphregion(margin(zero) lc(white))  ytitle("") ysc(range(0 5.5))  outergap(0) stack ylabel(0(.5)5.5, gstyle(major) nolab notick) 
	
   
	graph combine IFR IFR_GBDReg`GBDReg_code' Adj IFRHSC_GBDReg`GBDReg_code'  Severe IFRSEV96_GBDReg`GBDReg_code' ,  title("") scheme(s1mono) c(2) imargin(zero) name(ifrs`GBDReg_code', replace) xcommon ycommon

		*/
  local namegraphs `namegraphs' names`GBDReg_code'
  local popgraphs `popgraphs' pops`GBDReg_code'
*  local comgraphs `comgraphs' coms`GBDReg_code'
  local ifrgraphs `ifrgraphs' ifrs`GBDReg_code'
*  local sexgraphs `sexgraphs' sex`GBDReg_code'
  }
  
  global namegraphs `namegraphs' 
  global popgraphs `popgraphs' 
  global ifrgraphs `ifrgraphs' 

  graph combine  $popgraphs, title("Population" , size(large)) subtitle( "Morbidity and age", size(medsmall)) scheme(s1mono) c(1) imargin(small) xcommon name(popgraphs, replace) fxsize(30)
  *graph combine  `comgraphs', title("Comorbidities") scheme(s1mono) c(1) imargin(zero) xcommon name(comgraphs, replace) fxsize(35)
  *graph combine  `sexgraphs', title("Gender", size(large)) scheme(s1mono) c(1) imargin(small) xcommon name(sexgraphs, replace) fxsize(30)
  
  *graph combine popgraphs sexgraphs,  title("Population") scheme(s1mono) c(2) imargin(small) xcommon name(sexpopgraphs, replace) fxsize(30)
  
  graph combine  $namegraphs, title("Region" ) subtitle( "total population", size(medsmall)) scheme(s1mono) c(1) imargin(small) xcommon  name(namegraphs, replace)  fxsize(30)

  graph combine  $ifrgraphs, title("IFRs and Severe cases" ) subtitle( "in percentage points", size(medsmall)) scheme(s1mono) c(1) imargin(small) xcommon  name(ifrgraphs, replace) ycommon  fxsize(40)
  
	  graph combine namegraphs popgraphs ifrgraphs, title("") scheme(s1mono) c(4) imargin(zero) xcommon ysize(10)  ycommon
	
	graph export "$mypath\age and comorbidity adjusted IFRs\graphs_stata\Figure1_hsc.png", replace height(2000)
